@@ -4,7 +4,7 @@ library(logitr)
 test_that("getStartPars returns all 0s for first iteration in a multistart loop (and not other iterations)", {
   modelInputs <- getModelInputs(
     data = yogurt,
-    choice = "choice",
+    outcome = "choice",
     obsID = "obsID",
     pars = c("price", "feat"),
     price = NULL,
@@ -15,13 +15,15 @@ test_that("getStartPars returns all 0s for first iteration in a multistart loop
     panelID = NULL,
     clusterID = NULL,
     robust = FALSE,
+    startParBounds = c(-1, 1),
+    startVals = NULL,
     numMultiStarts  = 1,
     useAnalyticGrad = TRUE,
-    scaleInputs     = TRUE,
-    startParBounds  = c(-1, 1),
-    standardDraws   = NULL,
-    numDraws        = 50,
-    startVals       = NULL,
+    scaleInputs = TRUE,
+    standardDraws = NULL,
+    numDraws = 50,
+    vcov = FALSE,
+    predict = TRUE,
     call = NULL,
     options         = list(
       print_level = 0,
@@ -44,7 +46,7 @@ test_that("getStartPars returns all 0s for first iteration in a multistart loop
 test_that("getStartPars returns user-provided starting parameters for first iteration in a multistart loop (and not other iterations)", {
   modelInputs <- getModelInputs(
     data = yogurt,
-    choice = "choice",
+    outcome = "choice",
     obsID = "obsID",
     pars = c("price", "feat"),
     price = NULL,
@@ -55,13 +57,15 @@ test_that("getStartPars returns user-provided starting parameters for first iter
     panelID = NULL,
     clusterID = NULL,
     robust = FALSE,
-    numMultiStarts  = 1,
+    startParBounds = c(-1, 1),
+    startVals = c(1, 1),
+    numMultiStarts = 1,
     useAnalyticGrad = TRUE,
-    scaleInputs     = TRUE,
-    startParBounds  = c(-1, 1),
-    standardDraws   = NULL,
-    numDraws        = 50,
-    startVals       = c(1, 1),
+    scaleInputs = TRUE,
+    standardDraws = NULL,
+    numDraws = 50,
+    vcov = FALSE,
+    predict = TRUE,
     call = NULL,
     options         = list(
       print_level = 0,
